"use strict";

require("core-js/modules/es.object.define-property.js");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createLogHandler = void 0;
require("core-js/modules/es.array.concat.js");
require("core-js/modules/es.date.to-string.js");
require("core-js/modules/es.function.name.js");
var _interceptor = require("../../utilities/interceptor");
var _misc = require("../../utilities/misc");
var _type = require("../type");
var _logSerializer = require("./log-serializer");
var formatCallLog = function formatCallLog(identifier, args) {
  var msg = '';
  if (args.length) {
    msg += "[parameters: ".concat((0, _logSerializer.serializeArgs)(args), "]");
  }
  return "".concat(identifier.className, " ").concat(identifier.methodName, " [API Call] ").concat(identifier.traceId, " ").concat(msg);
};
var formatReturnLog = function formatReturnLog(identifier, elapsed, args, returnValue, thrown) {
  var msg = '';
  if (args !== null && args !== void 0 && args.length) {
    msg += "[parameters: ".concat((0, _logSerializer.serializeArgs)(args), "]");
  }
  if (thrown) {
    msg += "[throw: ".concat(thrown.name, "]");
    msg += "[message: ".concat(thrown.message, "]");
  } else if (typeof returnValue !== 'undefined') {
    msg += "[return: ".concat((0, _logSerializer.serialize)(returnValue), "]");
  }
  return "".concat(identifier.className, " ").concat(identifier.methodName, " [API Call]").concat(msg, "[elapsed: ").concat(elapsed, "ms]");
};
var createLogHandler = exports.createLogHandler = function createLogHandler(logger) {
  return function (evt) {
    if (evt.type === _type.InvocationEventType.PRE) {
      evt.context.start = new Date().getTime();
      evt.context.traceId = (0, _misc.randomString)(5);

      // const args = evt.arguments ?? [];
      // const msg = formatCallLog(
      //   {
      //     className: evt.class,
      //     methodName: evt.method,
      //     traceId: evt.context.traceId,
      //   },
      //   args,
      // );
      // logger.info(msg);
    } else {
      var _evt$arguments;
      var elapsed = new Date().getTime() - evt.context.start;
      var msg = formatReturnLog({
        className: evt["class"],
        methodName: evt.method,
        traceId: evt.context.traceId
      }, elapsed, (_evt$arguments = evt.arguments) !== null && _evt$arguments !== void 0 ? _evt$arguments : [], evt["return"], evt.error);
      logger.info(msg);
    }
    return _interceptor.Result.CONTINUE;
  };
};