type RetryOptions = {
    retriesMax?: number;
    interval?: number;
    exponential?: boolean;
    maxBackoff?: number;
    factor?: number;
    jitter?: number;
    isCb?: boolean;
};
type RetryAttemptArgs = {
    error: Error;
    currentRetry: number;
    retriesMax: number;
    interval: number;
    exponential: number;
    factor: number;
    jitter: number;
    maxBackoff: number;
};
type AnyFunction = (...args: any[]) => unknown;
type AbortCallback = (e: Error) => Promise<void> | void;
type AttemptFailCallback = (args: RetryAttemptArgs & {
    timeFn: () => Promise<void>;
}) => Promise<boolean> | boolean;
declare class Retry {
    private fn;
    private args;
    private onRetryAttemptFail?;
    private onRetryAbort?;
    private opts?;
    /**
     * @param fn target function
     * @param args arguments the target function to be called with
     * @param opts options
     */
    constructor(fn: AnyFunction, args: unknown[], opts?: RetryOptions);
    /**
     *
     * Registers a callback to be called when the target function fails
     * This callback function can be used to manage, by yourself, the retry system. It's called when an error occurred and before to retry. This method can have three behaviors:
     * you can throw an error
     * if it returns truthy value then normal retry system continues
     * if it returns falsy value then the retry system stop
     *
     * @param fn callback function to be called
     * @returns
     */
    fail(fn: AttemptFailCallback): this;
    /**
     * Registers a callback to be called when the target function and all retries fail
     *
     * @param fn callback function to be called
     * @returns
     */
    abort(fn: AbortCallback): this;
    /**
     * Starts executes the target function
     * retriesMax would be 3 and maxBackoff would be 10000(10 sceonds) by default
     */
    exec(): Promise<void>;
}
export declare const retryAttempt: (fn: AnyFunction, args: unknown[], opts?: RetryOptions) => Retry;
export {};
